'use client'

import React from 'react'
import { motion } from 'framer-motion'
import Image from 'next/image'

interface FeatureCardProps {
  title: string
  description: string
  imageSrc: string
}

const featureCards: FeatureCardProps[] = [
  {
    title: "Gutenberg Block",
    description: "Quickly select and add any module using our custom Gutenberg block to your pages or posts.",
    imageSrc: "/placeholder.svg?height=50&width=50"
  },
  {
    title: "Shortcode",
    description: "Embed our modules anywhere using shortcodes, the most versatile way to add features to your platform.",
    imageSrc: "/placeholder.svg?height=50&width=50"
  }
]

const FeatureCard: React.FC<FeatureCardProps> = ({ title, description, imageSrc }) => {
  return (
    <motion.div 
      className="ops-feature-card bg-white rounded-lg shadow-lg p-6"
      initial={{ opacity: 0, y: 50 }}
      whileInView={{ opacity: 1, y: 0 }}
      viewport={{ once: true }}
      transition={{ duration: 0.5 }}
      whileHover={{ scale: 1.05 }}
    >
      <Image src={imageSrc} alt={title} width={50} height={50} className="ops-feature-image mb-4" />
      <h3 className="ops-feature-title text-xl font-bold mb-2">{title}</h3>
      <p className="ops-feature-description text-gray-600">{description}</p>
    </motion.div>
  )
}

const OurProductSection: React.FC = () => {
  return (
    <section className="ops-section bg-gray-100 py-16 px-4">
      <div className="ops-container max-w-6xl mx-auto">
        <div className="ops-content grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
          <motion.div 
            className="ops-text-content"
            initial={{ opacity: 0, x: -50 }}
            whileInView={{ opacity: 1, x: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.5 }}
          >
            <h2 className="ops-title text-4xl md:text-5xl font-bold mb-4">
              Publish Our Product Modules
              <br />
              <span className="ops-subtitle bg-clip-text text-transparent bg-gradient-to-r from-pink-500 to-orange-500">
                Anywhere You Want
              </span>
            </h2>
            <p className="ops-description text-gray-600 mb-6">
              Our product integrates seamlessly into your environment and works with
              <span className="ops-highlight text-pink-500 font-semibold"> YOUR </span>
              favorite platform.
            </p>
            <motion.button 
              className="ops-learn-more-btn bg-pink-500 text-white px-6 py-3 rounded-full font-semibold"
              whileHover={{ scale: 1.05 }}
              whileTap={{ scale: 0.95 }}
            >
              Learn More
            </motion.button>
          </motion.div>
          <div className="ops-feature-grid space-y-6">
            {featureCards.map((card, index) => (
              <FeatureCard key={index} {...card} />
            ))}
          </div>
        </div>
      </div>
    </section>
  )
}

export default OurProductSection